@@ -1,15 +1,9 @@
 # -*- coding: utf-8 -*-
-try:
-    from importlib import metadata
-    from importlib.metadata import version
-    from importlib.resources import files
+from importlib import metadata
+from importlib.metadata import version
 
-except ImportError:
-    from importlib_metadata import metadata, version
-    from importlib_resources import files
-
-from .console_script import sort_excel_file
-from .excel_definition import Exceldefinition
+from .console_script import generate_template, sort_excel_file, update_jira_access_token
+from .excel_definition import ExcelDefinition, ExcelDefinitionColumn
 from .excel_operation import (
     output_to_csv_file,
     output_to_excel_file,
@@ -29,7 +23,8 @@ from .story import (
 __version__ = version("sharry_jira_tool")
 
 __all__ = [
-    "Exceldefinition",
+    "ExcelDefinition",
+    "ExcelDefinitionColumn",
     "read_excel_file",
     "output_to_csv_file",
     "output_to_excel_file",
@@ -42,6 +37,8 @@ __all__ = [
     "sort_stories_by_property_and_order",
     "sort_stories_by_raise_ranking",
     "sort_excel_file",
+    "generate_template",
+    "update_jira_access_token",
 ]
 
 del metadata
