@@ -328,12 +328,24 @@ def process_excel_file(
         story_id: str = story["storyId"].lower().strip()
         if story_id in jira_query_result:
             story["status"] = jira_query_result[story_id]
-            if story["status"].upper() in noneed_sort_statuses:
-                story.need_sort = False
+        else:
+            # Story ID has been changed because of convertion.
+            temp_result = jira_client.get_stories_status([story_id])
+            if len(temp_result) > 0:
+                story["storyId"] = list(temp_result.keys())[0]
+                story["status"] = list(temp_result.values())[0]
+            else:
                 stories_no_need_sort.append(story)
                 continue
+
+        if story["status"].upper() in noneed_sort_statuses:
+            story.need_sort = False
+            stories_no_need_sort.append(story)
+            continue
+
         stories_need_sort.append(story)
 
+    # Execute sorting logic.
     sort_strategies = excel_definition.get_sort_strategies()
 
     for sort_strategy in sort_strategies:
