@@ -21,6 +21,14 @@ class Milestone(object):
         self.sprint = self.raw
         self.priority = 0
 
+    @property
+    def priority(self) -> int:
+        return self._priority
+
+    @priority.setter
+    def priority(self, value: int):
+        self._priority = value
+
     def calc_priority(self, sprint_schedule: SprintScheduleStore) -> None:
         if self.sprint is None:
             self.priority = 0
@@ -33,19 +41,31 @@ class Milestone(object):
         else:
             return self.raw
 
-    def __lt__(self, __o: object) -> bool:
+    def __lt__(self, __o: "Milestone") -> bool:
         if self.priority < __o.priority:
             return True
         else:
             return False
 
-    def __le__(self, __o: object) -> bool:
+    def __gt__(self, __o: "Milestone") -> bool:
+        if self.priority > __o.priority:
+            return True
+        else:
+            return False
+
+    def __le__(self, __o: "Milestone") -> bool:
         if self.priority <= __o.priority:
             return True
         else:
             return False
 
-    def __eq__(self, __o: object) -> bool:
+    def __ge__(self, __o: "Milestone") -> bool:
+        if self.priority >= __o.priority:
+            return True
+        else:
+            return False
+
+    def __eq__(self, __o: "Milestone") -> bool:
         if self.priority == __o.priority:
             return True
         else:
